Struct samling::NestedStyleSummary
source · pub struct NestedStyleSummary {
pub id: Id<Style>,
pub number: String,
pub name: I18nString,
pub colors: Vec<NestedColorSummary>,
}Expand description
Style nested with colors and sizes, with some metadata fields excluded
Fields
id: Id<Style>number: Stringname: I18nStringcolors: Vec<NestedColorSummary>Trait Implementations
sourceimpl Clone for NestedStyleSummary
impl Clone for NestedStyleSummary
sourcefn clone(&self) -> NestedStyleSummary
fn clone(&self) -> NestedStyleSummary
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NestedStyleSummary
impl Debug for NestedStyleSummary
sourceimpl<'de> Deserialize<'de> for NestedStyleSummary
impl<'de> Deserialize<'de> for NestedStyleSummary
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for NestedStyleSummary
impl JsonSchema for NestedStyleSummary
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl RefUnwindSafe for NestedStyleSummary
impl Send for NestedStyleSummary
impl Sync for NestedStyleSummary
impl Unpin for NestedStyleSummary
impl UnwindSafe for NestedStyleSummary