Struct samling::PriceListSummary
source · pub struct PriceListSummary {
pub id: Id<PriceList>,
pub slug: Slug<PriceList>,
pub external_id: Option<ExternalId<PriceList>>,
pub name: String,
}Expand description
Price list summary
Fields
id: Id<PriceList>slug: Slug<PriceList>external_id: Option<ExternalId<PriceList>>name: StringTrait Implementations
sourceimpl Clone for PriceListSummary
impl Clone for PriceListSummary
sourcefn clone(&self) -> PriceListSummary
fn clone(&self) -> PriceListSummary
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PriceListSummary
impl Debug for PriceListSummary
sourceimpl<'de> Deserialize<'de> for PriceListSummary
impl<'de> Deserialize<'de> for PriceListSummary
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for PriceListSummary
impl JsonSchema for PriceListSummary
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl RefUnwindSafe for PriceListSummary
impl Send for PriceListSummary
impl Sync for PriceListSummary
impl Unpin for PriceListSummary
impl UnwindSafe for PriceListSummary